use clap::Parser;
use std::path::PathBuf;

#[derive(Parser, Debug)]
#[command(author, version, about, long_about = None)]
pub struct Args {
    /// Path to the source JSON config with original URLs.
    #[arg(long, required = true)]
    pub input_config: PathBuf,

    /// Path to the directory for downloaded rule files.
    #[arg(long, required = true)]
    pub rules_dir: PathBuf,

    /// Path where the rewritten, client-facing JSON config will be saved.
    #[arg(long, required = true)]
    pub output_config: PathBuf,

    /// Number of concurrent download operations.
    #[arg(long, default_value_t = 10)]
    pub concurrency: usize,

    /// The domain to use for rewriting rule URLs (e.g., "mydomain.com").
    #[arg(long, required = true)]
    pub domain: String,

    /// The path on the domain for the rewritten rule URLs (e.g., "rules").
    #[arg(long, name = "rule-path", required = true)]
    pub rule_path: String,

    /// Increase logging verbosity.
    #[arg(short, long, action = clap::ArgAction::Count)]
    pub verbose: u8,
}
